@@ -2,7 +2,6 @@
 #' @useDynLib L0Learn
 #' @importFrom Rcpp evalCpp
 #' @importFrom methods as
-#' @importFrom graphics arrows plot
 #' @import Matrix
 
 #' @title Fit an L0-regularized model
@@ -45,6 +44,7 @@
 #' @param lambdaGrid A vector of Lambda values to use in computing the regularization path. This is ignored unless autoLambda = FALSE.
 #' @param excludeFirstK This parameter takes non-negative integers. The first excludeFirstK features in x will be excluded from variable selection,
 #' i.e., the first excludeFirstK variables will not be included in the L0-norm penalty (they will still be included in the L1 or L2 norm penalties.).
+#' @param intercept If FALSE, no intercept term is included in the model.
 #' @return An S3 object of type "L0Learn" describing the regularization path. The object has the following members.
 #' \item{a0}{a0 is a list of intercept sequences. The ith element of the list (i.e., a0[[i]]) is the sequence of intercepts corresponding to the ith gamma value (i.e., gamma[i]).}
 #' \item{beta}{This is a list of coefficient matrices. The ith element of the list is a p x \code{length(lambda)} matrix which
@@ -86,12 +86,36 @@
 #' @export
 L0Learn.fit <- function(x,y, loss="SquaredError", penalty="L0", algorithm="CD", maxSuppSize=100, nLambda=100, nGamma=10,
 						gammaMax=10, gammaMin=0.0001, partialSort = TRUE, maxIters=200,
-						tol=1e-6, activeSet=TRUE, activeSetNum=3, maxSwaps=100, scaleDownFactor=0.8, screenSize=1000, autoLambda = TRUE, lambdaGrid = list(0), excludeFirstK=0)
+						tol=1e-6, activeSet=TRUE, activeSetNum=3, maxSwaps=100, scaleDownFactor=0.8, screenSize=1000, autoLambda = TRUE, lambdaGrid = list(0), excludeFirstK=0, intercept = TRUE)
 {
-	# The C++ function uses LambdaU = 1 for user-specified grid. In R, we use autoLambda0 = 0 for user-specified grid (thus the negation when passing the paramter to the function below)
-	M <- .Call('_L0Learn_L0LearnFit', PACKAGE = 'L0Learn', x, y, loss, penalty, algorithm, maxSuppSize, nLambda, nGamma, gammaMax, gammaMin, partialSort, maxIters, tol, activeSet, activeSetNum, maxSwaps, scaleDownFactor, screenSize, !autoLambda, lambdaGrid, excludeFirstK)
+	# The C++ function uses LambdaU = 1 for user-specified grid. In R, we use autoLambda0 = 0 for user-specified grid (thus the negation when passing the parameter to the function below)
+	M <- .Call('_L0Learn_L0LearnFit', PACKAGE = 'L0Learn', x, y, loss, penalty, algorithm, maxSuppSize, nLambda, nGamma, gammaMax, gammaMin, partialSort, maxIters, tol, activeSet, activeSetNum, maxSwaps, scaleDownFactor, screenSize, !autoLambda, lambdaGrid, excludeFirstK, intercept)
+
+	settings = list()
+	settings[[1]] = intercept # Settings only contains intercept for now. Might include additional elements later.
+	names(settings) <- c("intercept")
+
+	# Find potential support sizes exceeding maxSuppSize and remove them (this is due to
+	# the C++ core whose last solution can exceed maxSuppSize
+	for (i in 1:length(M$SuppSize)){
+			last = length(M$SuppSize[[i]])
+			if (M$SuppSize[[i]][last] > maxSuppSize){
+					if (last == 1){
+							print("Warning! Only 1 element in path with support size > maxSuppSize.")
+							print("Try increasing maxSuppSize to resolve the issue.")
+					}
+					else{
+							M$SuppSize[[i]] = M$SuppSize[[i]][-last]
+							M$Converged[[i]] = M$Converged[[i]][-last]
+							M$lambda[[i]] = M$lambda[[i]][-last]
+							M$a0[[i]] = M$a0[[i]][-last]
+							M$beta[[i]] = M$beta[[i]][,-last]
+					}
+			}
+	}
+
+	G <- list(beta = M$beta, lambda=lapply(M$lambda,signif, digits=6), a0=M$a0, converged = M$Converged, suppSize= M$SuppSize, gamma=M$gamma, penalty=penalty, loss=loss, settings = settings)
 
-	G <- list(beta = M$beta, lambda=lapply(M$lambda,signif, digits=6), a0=M$a0, converged = M$Converged, suppSize= M$SuppSize, gamma=M$gamma, penalty=penalty, loss=loss)
 
 	if (is.null(colnames(x))){
 			varnames <- 1:dim(x)[2]
